==> agr-center-domain-3.1.0-CLOUD-DEV-20230731.090500-43-sources.jar: com/tydic/dyc/agr/repository/AgrAgrChngRepository.java <==
package com.tydic.dyc.agr.repository; 

import com.tydic.dyc.agr.model.agrchange.AgrChngApplyDo;
import com.tydic.dyc.agr.model.agrchange.qrybo.AgrAgrChngApplyQryBo;
import com.tydic.dyc.agr.model.agrchange.qrybo.AgrItemChngListQryReqPageBo;
import com.tydic.dyc.agr.model.agrchange.qrybo.AgrItemChngListQryRspPageBo;
import com.tydic.dyc.agr.model.agrchange.qrybo.AgrAgrChngApplyListRspBO;

/**
 * 描述： 
 * 
 * @author auto_gen
 * @date 2023-04-23 19:08
 **/
public interface AgrAgrChngRepository {
	/**
	 * 协议变更申请新增
	 */
	 void saveAgrChngApply(AgrChngApplyDo agrChngApplyDo);
	/**
	 * 协议变更申请修改
	 */
	 void updateAgrChngApply(AgrChngApplyDo agrChngApplyDo);
	/**
	 * 协议主体变更新增
	 */
	 void saveAgrMainChng(AgrChngApplyDo agrChngApplyDo);
	/**
	 * 协议主体变更删除
	 */
	 void deleteAgrMainChng(AgrChngApplyDo agrChngApplyDo);
	/**
	 * 协议明细变更删除
	 */
	 void deleteAgrItemChng(AgrChngApplyDo agrChngApplyDo);
	/**
	 * 协议变更申请详情查询
	 */
	 AgrChngApplyDo getAgrChngApplyDetail(AgrAgrChngApplyQryBo agrAgrChngApplyQryBo);
	/**
	 * 协议主体变更详情查询
	 */
	 AgrChngApplyDo getAgrMainChngDetail(AgrAgrChngApplyQryBo agrAgrChngApplyQryBo);
	/**
	 * 协议明细变更新增
	 */
	 void saveAgrItemChng(AgrChngApplyDo agrChngApplyDo);
	/**
	 * 协议明细变更列表查询
	 */
	 AgrItemChngListQryRspPageBo getAgrItemChngList(AgrItemChngListQryReqPageBo agrItemChngListQryReqPageBo);
	/**
	 * 协议变更申请主体修改
	 */
	 void updateAgrChngApplyMain(AgrChngApplyDo agrChngApplyDo);
	/**
	 * 协议变更申请主体删除
	 */
	 void deleteAgrChngApplyMain(AgrChngApplyDo agrChngApplyDo);
	/**
	 * AGRR0040-变更申请主体列表查询
	 */
	 AgrAgrChngApplyListRspBO getAgrChngApplyList(AgrAgrChngApplyQryBo agrAgrChngApplyQryBo);
	/**
	 * AGRR0041-修改协议明细变更指定字段
	 */
	 void updateAgrChngItemSpecifyField(AgrChngApplyDo agrChngApplyDo);
	/**
	 * AGRR0042-协议明细变更新增校验
	 */
	 void checkAgrChngItemSave(AgrChngApplyDo agrChngApplyDo);

}

==> agr-center-domain-3.3.0-CLOUD-DEV-20250212.060224-1-sources.jar: com/tydic/dyc/agr/repository/AgrAgrChngRepository.java <==
package com.tydic.dyc.agr.repository; 

import com.tydic.dyc.agr.model.agrchange.AgrChngApplyDo;
import com.tydic.dyc.agr.model.agrchange.qrybo.AgrAgrChngApplyQryBo;
import com.tydic.dyc.agr.model.agrchange.qrybo.AgrItemChngListQryReqPageBo;
import com.tydic.dyc.agr.model.agrchange.qrybo.AgrItemChngListQryRspPageBo;
import com.tydic.dyc.agr.model.agrchange.qrybo.AgrAgrChngApplyListRspBO;
import com.tydic.dyc.agr.model.agrchange.qrybo.AgrAgrChngApplyListQryReqPageBo;
import com.tydic.dyc.agr.model.agrchange.qrybo.AgrAgrChngApplyListQryRspPageBo;

/**
 * 描述： 
 * 
 * @author auto_gen
 * @date 2023-08-04 17:46
 **/
public interface AgrAgrChngRepository {
	/**
	 * 协议变更申请新增
	 */
	 void saveAgrChngApply(AgrChngApplyDo agrChngApplyDo);
	/**
	 * 协议变更申请修改
	 */
	 void updateAgrChngApply(AgrChngApplyDo agrChngApplyDo);
	/**
	 * 协议主体变更新增
	 */
	 void saveAgrMainChng(AgrChngApplyDo agrChngApplyDo);
	/**
	 * 协议主体变更删除
	 */
	 void deleteAgrMainChng(AgrChngApplyDo agrChngApplyDo);
	/**
	 * 协议明细变更删除
	 */
	 void deleteAgrItemChng(AgrChngApplyDo agrChngApplyDo);
	/**
	 * 协议变更申请详情查询
	 */
	 AgrChngApplyDo getAgrChngApplyDetail(AgrAgrChngApplyQryBo agrAgrChngApplyQryBo);
	/**
	 * 协议主体变更详情查询
	 */
	 AgrChngApplyDo getAgrMainChngDetail(AgrAgrChngApplyQryBo agrAgrChngApplyQryBo);
	/**
	 * 协议明细变更新增
	 */
	 void saveAgrItemChng(AgrChngApplyDo agrChngApplyDo);
	/**
	 * 协议明细变更列表查询
	 */
	 AgrItemChngListQryRspPageBo getAgrItemChngList(AgrItemChngListQryReqPageBo agrItemChngListQryReqPageBo);
	/**
	 * 协议变更申请主体修改
	 */
	 void updateAgrChngApplyMain(AgrChngApplyDo agrChngApplyDo);
	/**
	 * 协议变更申请主体删除
	 */
	 void deleteAgrChngApplyMain(AgrChngApplyDo agrChngApplyDo);
	/**
	 * AGRR0040-变更申请主体列表查询
	 */
	 AgrAgrChngApplyListRspBO getAgrChngApplyList(AgrAgrChngApplyQryBo agrAgrChngApplyQryBo);
	/**
	 * AGRR0041-修改协议明细变更指定字段
	 */
	 void updateAgrChngItemSpecifyField(AgrChngApplyDo agrChngApplyDo);
	/**
	 * AGRR0042-协议明细变更新增校验
	 */
	 void checkAgrChngItemSave(AgrChngApplyDo agrChngApplyDo);
	/**
	 * 变更申请分页查询
	 */
	 AgrAgrChngApplyListQryRspPageBo getAllChngByPage(AgrAgrChngApplyListQryReqPageBo agrAgrChngApplyListQryReqPageBo);
	/**
	 * 协议主体变更详情查询
	 */
	AgrChngApplyDo getAgrMainChng(AgrAgrChngApplyQryBo agrAgrChngApplyQryBo);
}
